@@ -1,7 +1,7 @@
 """
 Type annotations for datapipeline service literal definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datapipeline/literals.html)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datapipeline/literals/)
 
 Usage::
 
@@ -29,6 +29,7 @@ __all__ = (
     "ServiceName",
     "ResourceServiceName",
     "PaginatorName",
+    "RegionName",
 )
 
 
@@ -156,6 +157,7 @@ ServiceName = Literal[
     "frauddetector",
     "fsx",
     "gamelift",
+    "gamesparks",
     "glacier",
     "globalaccelerator",
     "glue",
@@ -354,3 +356,4 @@ ResourceServiceName = Literal[
     "sqs",
 ]
 PaginatorName = Literal["describe_objects", "list_pipelines", "query_objects"]
+RegionName = Literal["ap-northeast-1", "ap-southeast-2", "eu-west-1", "us-east-1", "us-west-2"]
