@@ -1,7 +1,7 @@
 """
 Type annotations for datapipeline service type definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datapipeline/type_defs.html)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datapipeline/type_defs/)
 
 Usage::
 
@@ -32,6 +32,7 @@ __all__ = (
     "CreatePipelineOutputTypeDef",
     "DeactivatePipelineInputRequestTypeDef",
     "DeletePipelineInputRequestTypeDef",
+    "DescribeObjectsInputDescribeObjectsPaginateTypeDef",
     "DescribeObjectsInputRequestTypeDef",
     "DescribeObjectsOutputTypeDef",
     "DescribePipelinesInputRequestTypeDef",
@@ -42,6 +43,7 @@ __all__ = (
     "GetPipelineDefinitionInputRequestTypeDef",
     "GetPipelineDefinitionOutputTypeDef",
     "InstanceIdentityTypeDef",
+    "ListPipelinesInputListPipelinesPaginateTypeDef",
     "ListPipelinesInputRequestTypeDef",
     "ListPipelinesOutputTypeDef",
     "OperatorTypeDef",
@@ -56,6 +58,7 @@ __all__ = (
     "PollForTaskOutputTypeDef",
     "PutPipelineDefinitionInputRequestTypeDef",
     "PutPipelineDefinitionOutputTypeDef",
+    "QueryObjectsInputQueryObjectsPaginateTypeDef",
     "QueryObjectsInputRequestTypeDef",
     "QueryObjectsOutputTypeDef",
     "QueryTypeDef",
@@ -126,6 +129,16 @@ DeletePipelineInputRequestTypeDef = TypedDict(
     },
 )
 
+DescribeObjectsInputDescribeObjectsPaginateTypeDef = TypedDict(
+    "DescribeObjectsInputDescribeObjectsPaginateTypeDef",
+    {
+        "pipelineId": str,
+        "objectIds": Sequence[str],
+        "evaluateExpressions": NotRequired[bool],
+        "PaginationConfig": NotRequired["PaginatorConfigTypeDef"],
+    },
+)
+
 DescribeObjectsInputRequestTypeDef = TypedDict(
     "DescribeObjectsInputRequestTypeDef",
     {
@@ -213,6 +226,13 @@ InstanceIdentityTypeDef = TypedDict(
     },
 )
 
+ListPipelinesInputListPipelinesPaginateTypeDef = TypedDict(
+    "ListPipelinesInputListPipelinesPaginateTypeDef",
+    {
+        "PaginationConfig": NotRequired["PaginatorConfigTypeDef"],
+    },
+)
+
 ListPipelinesInputRequestTypeDef = TypedDict(
     "ListPipelinesInputRequestTypeDef",
     {
@@ -336,6 +356,16 @@ PutPipelineDefinitionOutputTypeDef = TypedDict(
     },
 )
 
+QueryObjectsInputQueryObjectsPaginateTypeDef = TypedDict(
+    "QueryObjectsInputQueryObjectsPaginateTypeDef",
+    {
+        "pipelineId": str,
+        "sphere": str,
+        "query": NotRequired["QueryTypeDef"],
+        "PaginationConfig": NotRequired["PaginatorConfigTypeDef"],
+    },
+)
+
 QueryObjectsInputRequestTypeDef = TypedDict(
     "QueryObjectsInputRequestTypeDef",
     {
